:icon: material/database-outline

Data
====

Older instruments might not have a USB or even CF or SD card slot. In these
cases, data can only be transferred through a serial connection. The data
transfer commands can be used for simple download and upload operations.

.. tip::

    Serial data transfer does not require any command protocol, only that the
    instrument is capable of sending date through a serial line.

.. toctree::
    :maxdepth: 1

    download
    upload
